==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/RegistryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.RegistryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Details of the Registry
 * @property discoveryUrl Discovery URL for the Registry
 * @property intellectualPropertyPublisher IntellectualPropertyPublisher for the registry
 * @property managedResourceGroup ResourceId of the managed RG if the registry has system created resources
 * @property mlFlowRegistryUri MLFlow Registry URI for the Registry
 * @property privateEndpointConnections Private endpoint connections info used for pending connections in private link portal
 * @property publicNetworkAccess Is the Registry accessible from the internet?
 * Possible values: "Enabled" or "Disabled"
 * @property regionDetails Details of each region the registry is in
 */
public data class RegistryArgs(
    public val discoveryUrl: Output<String>? = null,
    public val intellectualPropertyPublisher: Output<String>? = null,
    public val managedResourceGroup: Output<ArmResourceIdArgs>? = null,
    public val mlFlowRegistryUri: Output<String>? = null,
    public val privateEndpointConnections: Output<List<RegistryPrivateEndpointConnectionArgs>>? =
        null,
    public val publicNetworkAccess: Output<String>? = null,
    public val regionDetails: Output<List<RegistryRegionArmDetailsArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.RegistryArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.RegistryArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.RegistryArgs.builder()
            .discoveryUrl(discoveryUrl?.applyValue({ args0 -> args0 }))
            .intellectualPropertyPublisher(intellectualPropertyPublisher?.applyValue({ args0 -> args0 }))
            .managedResourceGroup(
                managedResourceGroup?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .mlFlowRegistryUri(mlFlowRegistryUri?.applyValue({ args0 -> args0 }))
            .privateEndpointConnections(
                privateEndpointConnections?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .publicNetworkAccess(publicNetworkAccess?.applyValue({ args0 -> args0 }))
            .regionDetails(
                regionDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RegistryArgs].
 */
@PulumiTagMarker
public class RegistryArgsBuilder internal constructor() {
    private var discoveryUrl: Output<String>? = null

    private var intellectualPropertyPublisher: Output<String>? = null

    private var managedResourceGroup: Output<ArmResourceIdArgs>? = null

    private var mlFlowRegistryUri: Output<String>? = null

    private var privateEndpointConnections: Output<List<RegistryPrivateEndpointConnectionArgs>>? =
        null

    private var publicNetworkAccess: Output<String>? = null

    private var regionDetails: Output<List<RegistryRegionArmDetailsArgs>>? = null

    /**
     * @param value Discovery URL for the Registry
     */
    @JvmName("rtqnssjwusxuienn")
    public suspend fun discoveryUrl(`value`: Output<String>) {
        this.discoveryUrl = value
    }

    /**
     * @param value IntellectualPropertyPublisher for the registry
     */
    @JvmName("gfggutnhatwxombx")
    public suspend fun intellectualPropertyPublisher(`value`: Output<String>) {
        this.intellectualPropertyPublisher = value
    }

    /**
     * @param value ResourceId of the managed RG if the registry has system created resources
     */
    @JvmName("ligqkdaxovfbmoyn")
    public suspend fun managedResourceGroup(`value`: Output<ArmResourceIdArgs>) {
        this.managedResourceGroup = value
    }

    /**
     * @param value MLFlow Registry URI for the Registry
     */
    @JvmName("njrnjevergxegbeo")
    public suspend fun mlFlowRegistryUri(`value`: Output<String>) {
        this.mlFlowRegistryUri = value
    }

    /**
     * @param value Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("qpfxjmfltdwvnwxt")
    public suspend
    fun privateEndpointConnections(`value`: Output<List<RegistryPrivateEndpointConnectionArgs>>) {
        this.privateEndpointConnections = value
    }

    @JvmName("rqqyqifwscbjlbny")
    public suspend fun privateEndpointConnections(
        vararg
        values: Output<RegistryPrivateEndpointConnectionArgs>,
    ) {
        this.privateEndpointConnections = Output.all(values.asList())
    }

    /**
     * @param values Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("gnqqsifyctxladei")
    public suspend
    fun privateEndpointConnections(values: List<Output<RegistryPrivateEndpointConnectionArgs>>) {
        this.privateEndpointConnections = Output.all(values)
    }

    /**
     * @param value Is the Registry accessible from the internet?
     * Possible values: "Enabled" or "Disabled"
     */
    @JvmName("tqtvalwctepwneon")
    public suspend fun publicNetworkAccess(`value`: Output<String>) {
        this.publicNetworkAccess = value
    }

    /**
     * @param value Details of each region the registry is in
     */
    @JvmName("atgngurrwtfgkvhb")
    public suspend fun regionDetails(`value`: Output<List<RegistryRegionArmDetailsArgs>>) {
        this.regionDetails = value
    }

    @JvmName("nivkhuwqehjrbury")
    public suspend fun regionDetails(vararg values: Output<RegistryRegionArmDetailsArgs>) {
        this.regionDetails = Output.all(values.asList())
    }

    /**
     * @param values Details of each region the registry is in
     */
    @JvmName("dtvsnqwedeyyuknc")
    public suspend fun regionDetails(values: List<Output<RegistryRegionArmDetailsArgs>>) {
        this.regionDetails = Output.all(values)
    }

    /**
     * @param value Discovery URL for the Registry
     */
    @JvmName("wyfvekhqcykydsvw")
    public suspend fun discoveryUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.discoveryUrl = mapped
    }

    /**
     * @param value IntellectualPropertyPublisher for the registry
     */
    @JvmName("lmvbxhlyphtltxei")
    public suspend fun intellectualPropertyPublisher(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.intellectualPropertyPublisher = mapped
    }

    /**
     * @param value ResourceId of the managed RG if the registry has system created resources
     */
    @JvmName("fkhxvqlgxolergls")
    public suspend fun managedResourceGroup(`value`: ArmResourceIdArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedResourceGroup = mapped
    }

    /**
     * @param argument ResourceId of the managed RG if the registry has system created resources
     */
    @JvmName("bkxfjutxgjyxsckw")
    public suspend fun managedResourceGroup(argument: suspend ArmResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = ArmResourceIdArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managedResourceGroup = mapped
    }

    /**
     * @param value MLFlow Registry URI for the Registry
     */
    @JvmName("cakqsvfsiximkqcd")
    public suspend fun mlFlowRegistryUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mlFlowRegistryUri = mapped
    }

    /**
     * @param value Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("jdjfnloaikcgaylj")
    public suspend
    fun privateEndpointConnections(`value`: List<RegistryPrivateEndpointConnectionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateEndpointConnections = mapped
    }

    /**
     * @param argument Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("buvcpgkqwmahkmvj")
    public suspend
    fun privateEndpointConnections(argument: List<suspend RegistryPrivateEndpointConnectionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RegistryPrivateEndpointConnectionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.privateEndpointConnections = mapped
    }

    /**
     * @param argument Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("xldaaucjrpuxhsin")
    public suspend fun privateEndpointConnections(
        vararg
        argument: suspend RegistryPrivateEndpointConnectionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RegistryPrivateEndpointConnectionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.privateEndpointConnections = mapped
    }

    /**
     * @param argument Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("jchrdcxigqqqlueg")
    public suspend
    fun privateEndpointConnections(argument: suspend RegistryPrivateEndpointConnectionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RegistryPrivateEndpointConnectionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.privateEndpointConnections = mapped
    }

    /**
     * @param values Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("hsvmfekqpttgluqq")
    public suspend fun privateEndpointConnections(
        vararg
        values: RegistryPrivateEndpointConnectionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateEndpointConnections = mapped
    }

    /**
     * @param value Is the Registry accessible from the internet?
     * Possible values: "Enabled" or "Disabled"
     */
    @JvmName("ofwjgekvchlkufhv")
    public suspend fun publicNetworkAccess(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Details of each region the registry is in
     */
    @JvmName("addmeccyslgkiito")
    public suspend fun regionDetails(`value`: List<RegistryRegionArmDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regionDetails = mapped
    }

    /**
     * @param argument Details of each region the registry is in
     */
    @JvmName("cfhmxofdgavyjnxy")
    public suspend
    fun regionDetails(argument: List<suspend RegistryRegionArmDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RegistryRegionArmDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.regionDetails = mapped
    }

    /**
     * @param argument Details of each region the registry is in
     */
    @JvmName("jifxltojpdfprfen")
    public suspend fun regionDetails(
        vararg
        argument: suspend RegistryRegionArmDetailsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RegistryRegionArmDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.regionDetails = mapped
    }

    /**
     * @param argument Details of each region the registry is in
     */
    @JvmName("nrkfdcwrgskckqaw")
    public suspend
    fun regionDetails(argument: suspend RegistryRegionArmDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RegistryRegionArmDetailsArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.regionDetails = mapped
    }

    /**
     * @param values Details of each region the registry is in
     */
    @JvmName("xumkpgdwkxnxvuym")
    public suspend fun regionDetails(vararg values: RegistryRegionArmDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regionDetails = mapped
    }

    internal fun build(): RegistryArgs = RegistryArgs(
        discoveryUrl = discoveryUrl,
        intellectualPropertyPublisher = intellectualPropertyPublisher,
        managedResourceGroup = managedResourceGroup,
        mlFlowRegistryUri = mlFlowRegistryUri,
        privateEndpointConnections = privateEndpointConnections,
        publicNetworkAccess = publicNetworkAccess,
        regionDetails = regionDetails,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/RegistryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.RegistryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Details of the Registry
 * @property discoveryUrl Discovery URL for the Registry
 * @property intellectualPropertyPublisher IntellectualPropertyPublisher for the registry
 * @property managedResourceGroup ResourceId of the managed RG if the registry has system created resources
 * @property mlFlowRegistryUri MLFlow Registry URI for the Registry
 * @property privateEndpointConnections Private endpoint connections info used for pending connections in private link portal
 * @property publicNetworkAccess Is the Registry accessible from the internet?
 * Possible values: "Enabled" or "Disabled"
 * @property regionDetails Details of each region the registry is in
 */
public data class RegistryArgs(
    public val discoveryUrl: Output<String>? = null,
    public val intellectualPropertyPublisher: Output<String>? = null,
    public val managedResourceGroup: Output<ArmResourceIdArgs>? = null,
    public val mlFlowRegistryUri: Output<String>? = null,
    public val privateEndpointConnections: Output<List<RegistryPrivateEndpointConnectionArgs>>? =
        null,
    public val publicNetworkAccess: Output<String>? = null,
    public val regionDetails: Output<List<RegistryRegionArmDetailsArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.RegistryArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.RegistryArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.RegistryArgs.builder()
            .discoveryUrl(discoveryUrl?.applyValue({ args0 -> args0 }))
            .intellectualPropertyPublisher(intellectualPropertyPublisher?.applyValue({ args0 -> args0 }))
            .managedResourceGroup(
                managedResourceGroup?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .mlFlowRegistryUri(mlFlowRegistryUri?.applyValue({ args0 -> args0 }))
            .privateEndpointConnections(
                privateEndpointConnections?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .publicNetworkAccess(publicNetworkAccess?.applyValue({ args0 -> args0 }))
            .regionDetails(
                regionDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RegistryArgs].
 */
@PulumiTagMarker
public class RegistryArgsBuilder internal constructor() {
    private var discoveryUrl: Output<String>? = null

    private var intellectualPropertyPublisher: Output<String>? = null

    private var managedResourceGroup: Output<ArmResourceIdArgs>? = null

    private var mlFlowRegistryUri: Output<String>? = null

    private var privateEndpointConnections: Output<List<RegistryPrivateEndpointConnectionArgs>>? =
        null

    private var publicNetworkAccess: Output<String>? = null

    private var regionDetails: Output<List<RegistryRegionArmDetailsArgs>>? = null

    /**
     * @param value Discovery URL for the Registry
     */
    @JvmName("euubwypfbjjqwtug")
    public suspend fun discoveryUrl(`value`: Output<String>) {
        this.discoveryUrl = value
    }

    /**
     * @param value IntellectualPropertyPublisher for the registry
     */
    @JvmName("uinkbxgyxkpgldub")
    public suspend fun intellectualPropertyPublisher(`value`: Output<String>) {
        this.intellectualPropertyPublisher = value
    }

    /**
     * @param value ResourceId of the managed RG if the registry has system created resources
     */
    @JvmName("tpkaosqgvpkdykuh")
    public suspend fun managedResourceGroup(`value`: Output<ArmResourceIdArgs>) {
        this.managedResourceGroup = value
    }

    /**
     * @param value MLFlow Registry URI for the Registry
     */
    @JvmName("nynpxkedixrwttaw")
    public suspend fun mlFlowRegistryUri(`value`: Output<String>) {
        this.mlFlowRegistryUri = value
    }

    /**
     * @param value Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("cvvioorhuyyyeqin")
    public suspend
    fun privateEndpointConnections(`value`: Output<List<RegistryPrivateEndpointConnectionArgs>>) {
        this.privateEndpointConnections = value
    }

    @JvmName("ifrjhqnimpviwqyy")
    public suspend fun privateEndpointConnections(
        vararg
        values: Output<RegistryPrivateEndpointConnectionArgs>,
    ) {
        this.privateEndpointConnections = Output.all(values.asList())
    }

    /**
     * @param values Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("vnpulhjsxwygihhl")
    public suspend
    fun privateEndpointConnections(values: List<Output<RegistryPrivateEndpointConnectionArgs>>) {
        this.privateEndpointConnections = Output.all(values)
    }

    /**
     * @param value Is the Registry accessible from the internet?
     * Possible values: "Enabled" or "Disabled"
     */
    @JvmName("llxkyvksgewbypog")
    public suspend fun publicNetworkAccess(`value`: Output<String>) {
        this.publicNetworkAccess = value
    }

    /**
     * @param value Details of each region the registry is in
     */
    @JvmName("kvcgcmypsvrqgkgq")
    public suspend fun regionDetails(`value`: Output<List<RegistryRegionArmDetailsArgs>>) {
        this.regionDetails = value
    }

    @JvmName("mwpmgfkjbgkjcuoc")
    public suspend fun regionDetails(vararg values: Output<RegistryRegionArmDetailsArgs>) {
        this.regionDetails = Output.all(values.asList())
    }

    /**
     * @param values Details of each region the registry is in
     */
    @JvmName("jlcmuawyscicmawk")
    public suspend fun regionDetails(values: List<Output<RegistryRegionArmDetailsArgs>>) {
        this.regionDetails = Output.all(values)
    }

    /**
     * @param value Discovery URL for the Registry
     */
    @JvmName("daiwxpskyoynscaj")
    public suspend fun discoveryUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.discoveryUrl = mapped
    }

    /**
     * @param value IntellectualPropertyPublisher for the registry
     */
    @JvmName("xmiskwcbxakhkixv")
    public suspend fun intellectualPropertyPublisher(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.intellectualPropertyPublisher = mapped
    }

    /**
     * @param value ResourceId of the managed RG if the registry has system created resources
     */
    @JvmName("cwcwnnxoldqtoeex")
    public suspend fun managedResourceGroup(`value`: ArmResourceIdArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedResourceGroup = mapped
    }

    /**
     * @param argument ResourceId of the managed RG if the registry has system created resources
     */
    @JvmName("nmddcatpmkyltpfq")
    public suspend fun managedResourceGroup(argument: suspend ArmResourceIdArgsBuilder.() -> Unit) {
        val toBeMapped = ArmResourceIdArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managedResourceGroup = mapped
    }

    /**
     * @param value MLFlow Registry URI for the Registry
     */
    @JvmName("wvgoijvoauojukkq")
    public suspend fun mlFlowRegistryUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mlFlowRegistryUri = mapped
    }

    /**
     * @param value Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("fauidrfsskobkkpc")
    public suspend
    fun privateEndpointConnections(`value`: List<RegistryPrivateEndpointConnectionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateEndpointConnections = mapped
    }

    /**
     * @param argument Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("rtelhjupwofnnlah")
    public suspend
    fun privateEndpointConnections(argument: List<suspend RegistryPrivateEndpointConnectionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RegistryPrivateEndpointConnectionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.privateEndpointConnections = mapped
    }

    /**
     * @param argument Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("mciclhcqswrbypkk")
    public suspend fun privateEndpointConnections(
        vararg
        argument: suspend RegistryPrivateEndpointConnectionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RegistryPrivateEndpointConnectionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.privateEndpointConnections = mapped
    }

    /**
     * @param argument Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("kfphvjgjhtifkugr")
    public suspend
    fun privateEndpointConnections(argument: suspend RegistryPrivateEndpointConnectionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RegistryPrivateEndpointConnectionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.privateEndpointConnections = mapped
    }

    /**
     * @param values Private endpoint connections info used for pending connections in private link portal
     */
    @JvmName("bqyyixwfekplwmxk")
    public suspend fun privateEndpointConnections(
        vararg
        values: RegistryPrivateEndpointConnectionArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateEndpointConnections = mapped
    }

    /**
     * @param value Is the Registry accessible from the internet?
     * Possible values: "Enabled" or "Disabled"
     */
    @JvmName("kqvwdcgwmbvkqthi")
    public suspend fun publicNetworkAccess(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Details of each region the registry is in
     */
    @JvmName("tmpoxrtdmodditgd")
    public suspend fun regionDetails(`value`: List<RegistryRegionArmDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regionDetails = mapped
    }

    /**
     * @param argument Details of each region the registry is in
     */
    @JvmName("uhgoxfksmucktpsd")
    public suspend
    fun regionDetails(argument: List<suspend RegistryRegionArmDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RegistryRegionArmDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.regionDetails = mapped
    }

    /**
     * @param argument Details of each region the registry is in
     */
    @JvmName("sbrtfieyslmpvtys")
    public suspend fun regionDetails(
        vararg
        argument: suspend RegistryRegionArmDetailsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RegistryRegionArmDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.regionDetails = mapped
    }

    /**
     * @param argument Details of each region the registry is in
     */
    @JvmName("mhvdeagxivdnlwcp")
    public suspend
    fun regionDetails(argument: suspend RegistryRegionArmDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RegistryRegionArmDetailsArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.regionDetails = mapped
    }

    /**
     * @param values Details of each region the registry is in
     */
    @JvmName("foqwsklyawugsxco")
    public suspend fun regionDetails(vararg values: RegistryRegionArmDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regionDetails = mapped
    }

    internal fun build(): RegistryArgs = RegistryArgs(
        discoveryUrl = discoveryUrl,
        intellectualPropertyPublisher = intellectualPropertyPublisher,
        managedResourceGroup = managedResourceGroup,
        mlFlowRegistryUri = mlFlowRegistryUri,
        privateEndpointConnections = privateEndpointConnections,
        publicNetworkAccess = publicNetworkAccess,
        regionDetails = regionDetails,
    )
}
